Documentation
¶
Overview ¶
Package lazyio includes io.ReadClosers that will lazily load from a file or URL.
Index ¶
Constants ¶
const (
// StdIO can be passed to File to set Stdin as the default
StdIO = "-"
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Reader ¶
type Reader interface {
Read(p []byte) (n int, err error)
Close() error
Set(string) error
Get() any
String() string
}
Reader is an io.ReadCloser that can be used as a flag.Value.
func File ¶
File returns an io.Reader that lazily loads a file set as a flag.Value. Pass StdIO ("-") to read from standard input.
Click to show internal directories.
Click to hide internal directories.